import { jsx as _jsx } from "react/jsx-runtime";
/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { useState, useEffect } from 'react';
import { CodeCell } from '@jupyterlab/cells';
import { Box } from '@primer/react';
import CellAdapter from './CellAdapter';
import Lumino from '../lumino/Lumino';
import { useJupyter } from './../../jupyter/JupyterContext';
import useCellStore from './CellState';
export const Cell = (props) => {
    const { source = '', autoStart } = props;
    const { serverSettings, defaultKernel } = useJupyter();
    const cellStore = useCellStore();
    const [adapter, setAdapter] = useState();
    useEffect(() => {
        if (defaultKernel && serverSettings) {
            defaultKernel.ready.then(() => {
                const adapter = new CellAdapter({
                    source,
                    serverSettings,
                    kernel: defaultKernel,
                });
                cellStore.setAdapter(adapter);
                cellStore.setSource(source);
                adapter.codeCell.model.contentChanged.connect((cellModel, changedArgs) => {
                    cellStore.setSource(cellModel.sharedModel.getSource());
                });
                adapter.codeCell.outputArea.outputLengthChanged.connect((outputArea, outputsCount) => {
                    cellStore.setOutputsCount(outputsCount);
                });
                adapter.sessionContext.initialize().then(() => {
                    if (autoStart) {
                        const execute = CodeCell.execute(adapter.codeCell, adapter.sessionContext);
                        execute.then((msg) => {
                            cellStore.setKernelAvailable(true);
                        });
                    }
                });
                setAdapter(adapter);
            });
        }
    }, [source, defaultKernel, serverSettings]);
    return adapter ? (_jsx(Box, { sx: {
            '& .dla-Jupyter-Cell': {
                position: 'relative !important',
                contain: 'content !important',
            },
            '& .jp-Toolbar': {
                height: 'auto !important',
                position: 'relative',
            },
            '& .lm-BoxPanel': {
                position: 'relative',
            },
            '& .jp-Cell': {
                position: 'relative',
            },
            '& .jp-CodeCell': {
                height: 'auto !important',
                position: 'relative',
            },
            '& .jp-Cell-outputArea': {
                paddingBottom: '30px',
            },
            '& .jp-CodeMirrorEditor': {
                cursor: 'text !important',
            },
        }, children: _jsx(Lumino, { children: adapter.panel }) })) : (_jsx(Box, { children: "Loading Jupyter Cell..." }));
};
Cell.defaultProps = {
    source: '',
    autoStart: true,
};
export default Cell;
//# sourceMappingURL=Cell.js.map