/*
 * Copyright (c) 2021-2023 Datalayer, Inc.
 *
 * MIT License
 */
import { createStore } from 'zustand/vanilla';
import { useStore } from 'zustand';
export const outputStore = createStore((set, get) => ({
    outputs: new Map(),
    setOutputs: (outputs) => set((state) => ({ outputs })),
    selectJupyterSource: (id) => {
        return get().outputs.get(id)?.source;
    },
    selectJupyterSetSource: (id) => {
        return get().outputs.get(id)?.setSource;
    },
    selectDataset: (id) => {
        return get().outputs.get(id)?.dataset;
    },
    selectExecute: (id) => {
        return get().outputs.get(id)?.execute;
    },
    selectGrade: (id) => {
        return get().outputs.get(id)?.grade;
    },
    source: (source) => {
        const sourceId = source.sourceId;
        const outputs = get().outputs;
        const s = outputs.get(sourceId);
        if (s) {
            s.source = source;
        }
        else {
            outputs.set(sourceId, { source });
        }
        set((state) => ({ outputs }));
    },
    dataset: (dataset) => {
        const sourceId = dataset.sourceId;
        const outputs = get().outputs;
        const d = outputs.get(sourceId);
        if (d) {
            d.dataset = dataset;
        }
        else {
            outputs.set(sourceId, { dataset });
        }
        set((state) => ({ outputs }));
    },
    execute: (execute) => {
        const sourceId = execute.sourceId;
        const outputs = get().outputs;
        const e = outputs.get(sourceId);
        if (e) {
            e.execute = execute;
        }
        else {
            outputs.set(sourceId, { execute });
        }
        set((state) => ({ outputs }));
    },
    setSource: (setSource) => {
        const sourceId = setSource.sourceId;
        const outputs = get().outputs;
        const s = outputs.get(sourceId);
        if (s) {
            s.setSource = setSource;
        }
        else {
            outputs.set(sourceId, { setSource });
        }
        set((state) => ({ outputs }));
    },
    grade: (grade) => {
        const sourceId = grade.sourceId;
        const outputs = get().outputs;
        const g = outputs.get(sourceId);
        if (g) {
            g.grade = grade;
        }
        else {
            outputs.set(sourceId, { grade });
        }
        set((state) => ({ outputs }));
    },
}));
export function useOutputStore(selector) {
    return useStore(outputStore, selector);
}
export default useOutputStore;
//# sourceMappingURL=OutputState.js.map